Package: ggtibble
Title: Create Tibbles and Lists of 'ggplot' Figures for Reporting
Version: 1.0.3
Authors@R: 
    person("Bill", "Denney", email="wdenney@humanpredictions.com", role=c("aut", "cre"), comment=c(ORCID="0000-0002-5759-428X"))
Description: 
  Create tibbles and lists of 'ggplot' figures that can be modified as easily as
  regular 'ggplot' figures.  Typical use cases are for creating reports or web
  pages where many figures are needed with different data and similar
  formatting.
License: GPL (>= 3)
Encoding: UTF-8
Depends: R (>= 4.3)
Suggests: ggbreak, ggforce, quarto, rmarkdown, spelling, testthat (>=
        3.0.0), withr
Config/testthat/edition: 3
Imports: checkmate, dplyr, ggplot2, glue, knitr, purrr, rlang, tibble,
        tidyr, vctrs
URL: https://humanpred.github.io/ggtibble/,
        https://github.com/humanpred/ggtibble
BugReports: https://github.com/humanpred/ggtibble/issues
Language: en-US
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-14 20:23:27 UTC; bill
Author: Bill Denney [aut, cre] (ORCID: <https://orcid.org/0000-0002-5759-428X>)
Maintainer: Bill Denney <wdenney@humanpredictions.com>
Repository: CRAN
Date/Publication: 2026-05-14 20:50:10 UTC
Built: R 4.5.2; ; 2026-05-14 23:51:42 UTC; unix
