# Generated by roxygen2: do not edit by hand

S3method("%+%",default)
S3method("%+%",gglist)
S3method("%+%",ggtibble)
S3method(Ops,ggtibble)
S3method(as_gglist,"NULL")
S3method(as_gglist,default)
S3method(as_gglist,gg)
S3method(as_gglist,gglist)
S3method(as_gglist,labels)
S3method(as_gglist,list)
S3method(chooseOpsMethod,gglist)
S3method(chooseOpsMethod,ggtibble)
S3method(format,gglist)
S3method(ggsave,default)
S3method(ggsave,gglist)
S3method(ggsave,ggtibble)
S3method(ggtibble,data.frame)
S3method(knit_print,gg)
S3method(knit_print,gglist)
S3method(knit_print,ggtibble)
S3method(print,gglist)
S3method(vec_arith,gglist)
S3method(vec_arith.gglist,data.frame)
S3method(vec_arith.gglist,gg)
S3method(vec_arith.gglist,ggbreak_params)
S3method(vec_arith.gglist,gglist)
S3method(vec_arith.gglist,guides)
S3method(vec_arith.gglist,labels)
S3method(vec_arith.gglist,list)
S3method(vec_arith.gglist,uneval)
export("%+%")
export(as_gglist)
export(gglist)
export(ggplot)
export(ggsave)
export(ggtibble)
export(group_vars)
export(knit_print)
export(labs_glue)
export(new_gglist)
export(new_ggtibble)
export(vec_arith)
importFrom(dplyr,group_vars)
importFrom(ggplot2,ggplot)
importFrom(knitr,knit_print)
importFrom(vctrs,vec_arith)
